@@ -57,7 +57,7 @@ class SharedConnection : public sigc::trackable
 {
 public:
   SharedConnection();
-  SharedConnection(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connection);
+  explicit SharedConnection(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connection);
   virtual ~SharedConnection();
 
   Glib::RefPtr<Gnome::Gda::Connection> get_gda_connection();
@@ -279,6 +279,8 @@ public:
    */
   bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields) throw();
 
+  bool update_meta_store_for_table_names();
+
   /** Specify a callback that the ConnectionPool can call to get a pointer to the document.
    * This callback avoids Connection having to link to AppWindow,
    * and avoids us worrying about whether a previously-set document (via a set_document() method) is still valid.
